# =============================================
# 
# OBJET : CARTOGRAPHIE DES CENTRES DE RENTENTION POUR MIGRANTS
#
# Objectif 1 : Exemple de constructuion cartographique
# Objectif 2 : Faire une carte animée
# auteur : Nicolas Lambert, CNRS - UMS RIATE
# version : 1.0 (oct 2014)
#
# ===============================================

# -------------------------------------------------------------
# REALISATION D'UNE CARTE STATIQUE
# ------------------------------------------------------------

library(maptools)
library(rgeos)


setwd("- votre repertoire de travail - ")
camps <- readShapeSpatial("geom/camps_time.shp")
plot(camps)
countries<-readShapeSpatial("geom/countries.shp")
plot(countries,add=T)

# On definie l'étendue géographique
camps<-camps[camps@data$longitude>-20,]
camps<-camps[camps@data$latitude>-20,]
plot(camps)
extent<-gEnvelope(camps, byid=FALSE, id = NULL)
plot(extent, add=T)

# On aggrege les pays
countr<-gBuffer(countries, byid=FALSE, id=NULL, width=1000)
countr<-gBuffer(countr, byid=FALSE, id=NULL, width=-1000)
# On découpe les pays
countr<-gIntersection(countr, extent, byid=FALSE, id=NULL)
# Affichage
plot(countr,add=T)

# On n'affiche les camps d'une seule année => ANNEE 1992
head(camps@data)
camps_year<-camps[camps@data[,18]==1,]
plot(camps_year,type=p,pch=16,col="blue",cex=1,add=T)

# Creation d'un enveloppe convexe
hux<-gConvexHull(camps_year, byid=FALSE, id = NULL) 
plot(hux,add=T,col="#CCCCCC50")

# Ajout d'une zone tampon
buff<-gBuffer(hux, byid=FALSE, id=NULL, width=100000, quadsegs=5, capStyle="ROUND",joinStyle="ROUND", mitreLimit=1.0)
plot(buff,add=T,lwd=4)

# Extraction des pays couverts par la zone tampon (intersection)
area<-gIntersection(countr, buff, byid=FALSE, id=NULL)
plot(area,add=T,col="#FF000090",border="#FF0000")


# Carte
plot(countr)
plot(extent,add=T)
plot(area,add=T,col="#FF000090",border="#FF0000")
plot(camps_year,type=p,pch=16,bg="red",cex=1,add=T)
title("Les Centre de rétention pour migrants en Europe en 1992")

# -------------------------------------------------------------
# REALISATION D'UNE CARTE ANIMEE
# ------------------------------------------------------------

# Principe : on met notre process dans une fonction et on itère

library(animation)

# creation de la fonction
plotArea<-function(date){  i<-date-1976
  par(omi=c(0,0,0,0), mgp=c(0,0,0),mar=c(0,0,0,0) , family = "D")
  par(mfrow=c(1,1),cex=1,cex.lab = 0.75,cex.main=0.2,cex.axis=0.2)
  y1<-1000000
  y2<-3000000
  x1<-000000
  x2<-7000000
  plot(countr)
  plot(extent,add=T)
  
  camps_year<-camps[camps@data[,i]==1,]
  hux<-gConvexHull(camps_year, byid=FALSE, id = NULL) 
  buff<-gBuffer(hux, byid=FALSE, id=NULL, width=100000, quadsegs=5, capStyle="ROUND",joinStyle="ROUND", mitreLimit=1.0)
  area<-gIntersection(countr, buff, byid=FALSE, id=NULL)
  plot(area,add=T,col="#FF000090",border="#FF0000")
  plot(camps_year,type=p,pch=16,bg="red",cex=1,add=T)
  text(5910000, 4000000,"Principaux lieux d'enfermement\ndes migrants en ",cex = 1,family="arial",pos=4,col="#00000090",adj = c(0,0))
  text(6510000, 3900000,date,cex = 3,family="arial",pos=4,col="#00000090",adj = c(0,0))
  text(1600000, 300000,"(CC) Nicolas LAMBERT, 2014\nSources : http://closethecamps.org/",cex =  1,family="arial",pos=4,col="#00000080")
  rect(1462625, 4243391, 7206122, 4393391, col = "black", border = "black") 
  text(1462625, 4300000,"Externalisation de la politique migratoire de l'Union européenne, 1985-2013",cex = 1.7,family="arial",pos=4,col="#FFFFFF",adj = c(0,0))
  points(x=5870000,y=4030000,pch=16,add=T)
}

# Boucle pour appeler la fonction pour chaque année (chaque colonne)
carte.ani <- function() {
  for (i in 1985:2013) {
    plotArea(i)
    i<-i+1
  }
}

saveGIF(carte.ani(), interval = 0.3, autobrowse = FALSE, movie.name = "carteAnim.gif",  outdir = paste(getwd(), "/resul", sep = ""), ani.height = 700, ani.width = 1000)

